/*********************************************************************
*                SEGGER Microcontroller GmbH & Co. KG                *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2016 SEGGER Microcontroller GmbH & Co. KG         *
*                                                                    *
*     Internet: segger.com   Support: support_embos@segger.com       *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 4.16                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for STM32F103 (ST MB672)
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "RTOS.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

//
// GPIO
//
#define GPIO_BASE_ADDR         0x40010800

#define GPIOD_CRL_OFFS         0x0C00
#define GPIOD_IDR_OFFS         0x0C08
#define GPIOF_CRL_OFFS         0x1400
#define GPIOF_CRH_OFFS         0x1404
#define GPIOF_ODR_OFFS         0x140C
#define GPIOF_BSRR_OFFS        0x1410
#define GPIOF_BRR_OFFS         0x1414
#define GPIOG_CRL_OFFS         0x1800
#define GPIOG_CRH_OFFS         0x1804
#define GPIOG_IDR_OFFS         0x1808

#define GPIOD_CRL              (*(volatile OS_U32*)(GPIO_BASE_ADDR + GPIOD_CRL_OFFS))
#define GPIOD_IDR              (*(volatile OS_U32*)(GPIO_BASE_ADDR + GPIOD_IDR_OFFS))
#define GPIOF_CRL              (*(volatile OS_U32*)(GPIO_BASE_ADDR + GPIOF_CRL_OFFS))
#define GPIOF_CRH              (*(volatile OS_U32*)(GPIO_BASE_ADDR + GPIOF_CRH_OFFS))
#define GPIOF_ODR              (*(volatile OS_U32*)(GPIO_BASE_ADDR + GPIOF_ODR_OFFS))
#define GPIOF_BSRR             (*(volatile OS_U32*)(GPIO_BASE_ADDR + GPIOF_BSRR_OFFS))
#define GPIOF_BRR              (*(volatile OS_U32*)(GPIO_BASE_ADDR + GPIOF_BRR_OFFS))
#define GPIOG_CRL              (*(volatile OS_U32*)(GPIO_BASE_ADDR + GPIOG_CRL_OFFS))
#define GPIOG_CRH              (*(volatile OS_U32*)(GPIO_BASE_ADDR + GPIOG_CRH_OFFS))
#define GPIOG_IDR              (*(volatile OS_U32*)(GPIO_BASE_ADDR + GPIOG_IDR_OFFS))

#define GPIO_CR_PIN3_BIT       12
#define GPIO_CR_PIN7_BIT       28
#define GPIO_CR_PIN13_BIT      20
#define GPIO_CR_PIN14_BIT      24
#define GPIO_CR_PIN15_BIT      28

#define GPIO_IDR_PIN3           3
#define GPIO_IDR_PIN7           7
#define GPIO_IDR_PIN13         13
#define GPIO_IDR_PIN14         14
#define GPIO_IDR_PIN15         15

//
// Joystick
//
#define GPIO_PORT_JOYSTICK_CONF       0x04

#define GPIO_CR_JOYSTICK_LEFT_BIT     GPIO_CR_PIN14_BIT
#define GPIO_CR_JOYSTICK_RIGHT_BIT    GPIO_CR_PIN13_BIT
#define GPIO_CR_JOYSTICK_UP_BIT       GPIO_CR_PIN15_BIT
#define GPIO_CR_JOYSTICK_DOWN_BIT     GPIO_CR_PIN3_BIT
#define GPIO_CR_JOYSTICK_SELECT_BIT   GPIO_CR_PIN7_BIT

#define GPIO_IDR_JOYSTICK_SELECT_BIT  GPIO_IDR_PIN7
#define GPIO_IDR_JOYSTICK_DOWN_BIT    GPIO_IDR_PIN3
#define GPIO_IDR_JOYSTICK_LEFT_BIT    GPIO_IDR_PIN14
#define GPIO_IDR_JOYSTICK_RIGHT_BIT   GPIO_IDR_PIN13
#define GPIO_IDR_JOYSTICK_UP_BIT      GPIO_IDR_PIN15

//
// SYSCTRL
//
#define SYSCTRL_RCC_APB2   (*(volatile OS_U32*)0x40021018)

#define SYSCTRL_GPIOF_BIT  7

//
// LEDs
//
#define NUM_LEDS      4

#define LED0_BIT      6
#define LED1_BIT      7
#define LED2_BIT      8
#define LED3_BIT      9

#define LED_MASK_ALL  ((1uL << LED0_BIT) | (1uL << LED1_BIT) | (1uL << LED2_BIT) | (1uL << LED3_BIT))

/*********************************************************************
*
*       Local functions
*
**********************************************************************
*/

/*********************************************************************
*
*       _InitJoystick
*
*       Purpose: Configures the GPIO interface to enable the joystick
*/
static void _InitJoystick(void) {
  OS_U32 TempReg;

  TempReg    = GPIOD_CRL;
  TempReg   &= ~0xB000uL;
  TempReg   |= (GPIO_PORT_JOYSTICK_CONF << GPIO_CR_JOYSTICK_DOWN_BIT);
  GPIOD_CRL  = TempReg;

  TempReg    = GPIOG_CRL;
  TempReg   &= ~0xB0000000uL;
  TempReg   |= (GPIO_PORT_JOYSTICK_CONF << GPIO_CR_JOYSTICK_SELECT_BIT);
  GPIOG_CRL  = TempReg;

  TempReg    = GPIOG_CRH;
  TempReg   &= ~0xBBB00000uL;
  TempReg   |= ((GPIO_PORT_JOYSTICK_CONF << GPIO_CR_JOYSTICK_LEFT_BIT)
            |   (GPIO_PORT_JOYSTICK_CONF << GPIO_CR_JOYSTICK_RIGHT_BIT)
            |   (GPIO_PORT_JOYSTICK_CONF << GPIO_CR_JOYSTICK_UP_BIT))
            ;
  GPIOG_CRH  = TempReg;
}

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Setup LEDs
  //
  SYSCTRL_RCC_APB2 |= (1uL << SYSCTRL_GPIOF_BIT);
  GPIOF_CRL         = ((GPIOF_CRL & 0x00FFFFFFuL) | 0x33000000uL);
  GPIOF_CRH         = ((GPIOF_CRH & 0xFFFFFF00uL) | 0x00000033uL);
  GPIOF_BRR        |= LED_MASK_ALL;  // Disable all LEDs
  //
  // Init joystick
  //
  _InitJoystick();
}

/*********************************************************************
*
*       LED switching routines
*       LEDs are switched on with low level on port lines
*/
void BSP_SetLED(int Index) {
  if (Index > (NUM_LEDS - 1)) {
    return;
  }
  GPIOF_BSRR |= (1uL << (LED0_BIT + Index));             // Switch on LED
}

void BSP_ClrLED(int Index) {
  if (Index > (NUM_LEDS - 1)) {
    return;
  }
  GPIOF_BRR |= (1uL << (LED0_BIT + Index));              // Switch off LED
}

void BSP_ToggleLED(int Index) {
  if (Index > (NUM_LEDS - 1)) {
    return;
  }
  if ((GPIOF_ODR & (1uL << (LED0_BIT + Index))) == 0) {  // Toggle LED
    BSP_SetLED(Index);
  } else {
    BSP_ClrLED(Index);
  }
}

/*********************************************************************
*
*       BSP_GetKeyStat()
*/
unsigned BSP_GetKeyStat(void) {
  OS_U32 IdrG;
  unsigned r;

  r = 0;

  if ((GPIOD_IDR & (1 << GPIO_IDR_JOYSTICK_DOWN_BIT)) == 0) {
    r |= KEY_STAT_DOWN;      // Joystick down
  }
  IdrG = GPIOG_IDR;
  if ((IdrG & (1 << GPIO_IDR_JOYSTICK_LEFT_BIT)) == 0) {
    r |= KEY_STAT_LEFT;      // Joystick left
  }
  if ((IdrG & (1 << GPIO_IDR_JOYSTICK_RIGHT_BIT)) == 0) {
    r |= KEY_STAT_RIGHT;     // Joystick right
  }
  if ((IdrG & (1 << GPIO_IDR_JOYSTICK_UP_BIT)) == 0) {
    r |= KEY_STAT_UP;        // Joystick up
  }
  if ((IdrG & (1 << GPIO_IDR_JOYSTICK_SELECT_BIT)) == 0) {
    r |= KEY_STAT_BUTTON1;   // Joystick select
  }
  return r;
}

/*************************** End of file ****************************/
