/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2011  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: Internal                                         *
*                                                                    *
*       Current version number will be inserted here                 *
*       when shipment is built.                                      *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : stm32f207-eval-ram.ld
Purpose : Linker File for STM32F103
--------  END-OF-HEADER  ---------------------------------------------
*/

OUTPUT_FORMAT ("elf32-littlearm", "elf32-bigarm", "elf32-littlearm")
ENTRY(__cs3_reset)
SEARCH_DIR(.)
GROUP(-lgcc -lc -lcs3 -lcs3unhosted)

MEMORY
{
  ram (rwx) : ORIGIN = 0x20000000, LENGTH = 64k
  rom (rx) : ORIGIN = 0x08000000, LENGTH = 512k
  option_bytes_rom (rx) : ORIGIN = 0x1FFFF800, LENGTH = 16
  extnor (rx) : ORIGIN = 0x64000000, LENGTH = 16M
  extsram (rwx) : ORIGIN = 0x68000000, LENGTH = 1M
  extnand (rx) : ORIGIN = 0x70000000, LENGTH = 1M
}

EXTERN (__cs3_stack)
EXTERN (__cs3_reset)

/* These force the linker to search for particular symbols from
 * the start of the link process and thus ensure the user's
 * overrides are picked up
 */
EXTERN(__cs3_reset _start)
EXTERN(__cs3_start_asm _start)
/* Bring in the interrupt routines & vector */
EXTERN(__Vectors)
EXTERN(__cs3_start_c main __cs3_stack __cs3_heap_end)

/* Provide fall-back values */
PROVIDE(__cs3_heap_start = _end);
PROVIDE(__cs3_heap_end = __cs3_region_start_ram + __cs3_region_size_ram);
PROVIDE(__cs3_region_num = (__cs3_regions_end - __cs3_regions) / 20);
PROVIDE(__cs3_stack = __cs3_region_start_ram + __cs3_region_size_ram);

SECTIONS
{
  .text :
  {
    CREATE_OBJECT_SYMBOLS
    __cs3_region_start_ram = .;
    _ftext = .;
    *(.cs3.region-head.ram)
    ASSERT (. == __cs3_region_start_ram, ".cs3.region-head.ram not permitted");
    __cs3_interrupt_vector = __Vectors;
    *(.cs3.interrupt_vector)
    /* Make sure we pulled in an interrupt vector.  */
    PROVIDE(__cs3_reset = _start);
    *(.cs3.reset)

    *(.text.cs3.init)
    *(.text .text.* .gnu.linkonce.t.*)
    *(.plt)
    *(.gnu.warning)
    *(.glue_7t) *(.glue_7) *(.vfp11_veneer)

    *(.ARM.extab* .gnu.linkonce.armextab.*)
    *(.gcc_except_table)
  } >ram
  .eh_frame_hdr : ALIGN (4)
  {
    KEEP (*(.eh_frame_hdr))
  } >ram
  .eh_frame : ALIGN (4)
  {
    KEEP (*(.eh_frame))
  } >ram
  /* .ARM.exidx is sorted, so has to go in its own output section.  */
  PROVIDE_HIDDEN (__exidx_start = .);
  .ARM.exidx :
  {
    *(.ARM.exidx* .gnu.linkonce.armexidx.*)
  } >ram
  PROVIDE_HIDDEN (__exidx_end = .);
  .rodata : ALIGN (4)
  {
    *(.rodata .rodata.* .gnu.linkonce.r.*)

    . = ALIGN(4);
    KEEP(*(.init))

    . = ALIGN(4);
    __preinit_array_start = .;
    KEEP (*(.preinit_array))
    __preinit_array_end = .;

    . = ALIGN(4);
    __init_array_start = .;
    KEEP (*(SORT(.init_array.*)))
    KEEP (*(.init_array))
    __init_array_end = .;

    . = ALIGN(4);
    KEEP(*(.fini))

    . = ALIGN(4);
    __fini_array_start = .;
    KEEP (*(.fini_array))
    KEEP (*(SORT(.fini_array.*)))
    __fini_array_end = .;

    . = ALIGN(0x4);
    KEEP (*crtbegin.o(.ctors))
    KEEP (*(EXCLUDE_FILE (*crtend.o) .ctors))
    KEEP (*(SORT(.ctors.*)))
    KEEP (*crtend.o(.ctors))

    . = ALIGN(0x4);
    KEEP (*crtbegin.o(.dtors))
    KEEP (*(EXCLUDE_FILE (*crtend.o) .dtors))
    KEEP (*(SORT(.dtors.*)))
    KEEP (*crtend.o(.dtors))

    . = ALIGN(4);
    __cs3_regions = .;
    LONG (0)
    LONG (__cs3_region_init_ram)
    LONG (__cs3_region_start_ram)
    LONG (__cs3_region_init_size_ram)
    LONG (__cs3_region_zero_size_ram)
    LONG (0)
    LONG (__cs3_region_init_extnor)
    LONG (__cs3_region_start_extnor)
    LONG (__cs3_region_init_size_extnor)
    LONG (__cs3_region_zero_size_extnor)
    LONG (0)
    LONG (__cs3_region_init_extsram)
    LONG (__cs3_region_start_extsram)
    LONG (__cs3_region_init_size_extsram)
    LONG (__cs3_region_zero_size_extsram)
    LONG (0)
    LONG (__cs3_region_init_extnand)
    LONG (__cs3_region_start_extnand)
    LONG (__cs3_region_init_size_extnand)
    LONG (__cs3_region_zero_size_extnand)
    __cs3_regions_end = .;
    . = ALIGN (8);
    _etext = .;
  } >ram

  ASSERT (!(__cs3_region_init_ram & 7), "__cs3_region_init_ram not aligned")
  ASSERT (!(__cs3_region_start_ram & 7), "__cs3_region_start_ram not aligned")
  ASSERT (!(__cs3_region_init_size_ram & 7), "__cs3_region_init_size_ram not aligned")
  ASSERT (!(__cs3_region_zero_size_ram & 7), "__cs3_region_zero_size_ram not aligned")
  ASSERT (!(__cs3_region_init_extnor & 7), "__cs3_region_init_extnor not aligned")
  ASSERT (!(__cs3_region_start_extnor & 7), "__cs3_region_start_extnor not aligned")
  ASSERT (!(__cs3_region_init_size_extnor & 7), "__cs3_region_init_size_extnor not aligned")
  ASSERT (!(__cs3_region_zero_size_extnor & 7), "__cs3_region_zero_size_extnor not aligned")
  ASSERT (!(__cs3_region_init_extsram & 7), "__cs3_region_init_extsram not aligned")
  ASSERT (!(__cs3_region_start_extsram & 7), "__cs3_region_start_extsram not aligned")
  ASSERT (!(__cs3_region_init_size_extsram & 7), "__cs3_region_init_size_extsram not aligned")
  ASSERT (!(__cs3_region_zero_size_extsram & 7), "__cs3_region_zero_size_extsram not aligned")
  ASSERT (!(__cs3_region_init_extnand & 7), "__cs3_region_init_extnand not aligned")
  ASSERT (!(__cs3_region_start_extnand & 7), "__cs3_region_start_extnand not aligned")
  ASSERT (!(__cs3_region_init_size_extnand & 7), "__cs3_region_init_size_extnand not aligned")
  ASSERT (!(__cs3_region_zero_size_extnand & 7), "__cs3_region_zero_size_extnand not aligned")
  .cs3.rom : ALIGN (8)
  {
    __cs3_region_start_rom = .;
    *(.cs3.region-head.rom)
    *(.rom)
    . = ALIGN (8);
  } >rom
  .cs3.rom.bss :
  {
    *(.rom.b .bss.rom)
    . = ALIGN (8);
  } >rom
  /* __cs3_region_end_rom is deprecated */
  __cs3_region_end_rom = __cs3_region_start_rom + LENGTH(rom);
  __cs3_region_size_rom = LENGTH(rom);
  __cs3_region_init_rom = LOADADDR (.cs3.rom);
  __cs3_region_init_size_rom = LOADADDR (.cs3.rom.bss) - LOADADDR (.cs3.rom);
  __cs3_region_zero_size_rom = SIZEOF(.cs3.rom.bss);

  .cs3.option_bytes_rom : ALIGN (8)
  {
    __cs3_region_start_option_bytes_rom = .;
    *(.cs3.region-head.option_bytes_rom)
    *(.option_bytes_rom)
    . = ALIGN (8);
  } >option_bytes_rom
  .cs3.option_bytes_rom.bss :
  {
    *(.option_bytes_rom.b .bss.option_bytes_rom)
    . = ALIGN (8);
  } >option_bytes_rom
  /* __cs3_region_end_option_bytes_rom is deprecated */
  __cs3_region_end_option_bytes_rom = __cs3_region_start_option_bytes_rom + LENGTH(option_bytes_rom);
  __cs3_region_size_option_bytes_rom = LENGTH(option_bytes_rom);
  __cs3_region_init_option_bytes_rom = LOADADDR (.cs3.option_bytes_rom);
  __cs3_region_init_size_option_bytes_rom = LOADADDR (.cs3.option_bytes_rom.bss) - LOADADDR (.cs3.option_bytes_rom);
  __cs3_region_zero_size_option_bytes_rom = SIZEOF(.cs3.option_bytes_rom.bss);

  .cs3.extnor : ALIGN (8)
  {
    __cs3_region_start_extnor = .;
    *(.cs3.region-head.extnor)
    *(.extnor)
    . = ALIGN (8);
  } >extnor
  .cs3.extnor.bss :
  {
    *(.extnor.b .bss.extnor)
    . = ALIGN (8);
  } >extnor
  /* __cs3_region_end_extnor is deprecated */
  __cs3_region_end_extnor = __cs3_region_start_extnor + LENGTH(extnor);
  __cs3_region_size_extnor = LENGTH(extnor);
  __cs3_region_init_extnor = LOADADDR (.cs3.extnor);
  __cs3_region_init_size_extnor = LOADADDR (.cs3.extnor.bss) - LOADADDR (.cs3.extnor);
  __cs3_region_zero_size_extnor = SIZEOF(.cs3.extnor.bss);

  .cs3.extsram : ALIGN (8)
  {
    __cs3_region_start_extsram = .;
    *(.cs3.region-head.extsram)
    *(.extsram)
    . = ALIGN (8);
  } >extsram
  .cs3.extsram.bss :
  {
    *(.extsram.b .bss.extsram)
    . = ALIGN (8);
  } >extsram
  /* __cs3_region_end_extsram is deprecated */
  __cs3_region_end_extsram = __cs3_region_start_extsram + LENGTH(extsram);
  __cs3_region_size_extsram = LENGTH(extsram);
  __cs3_region_init_extsram = LOADADDR (.cs3.extsram);
  __cs3_region_init_size_extsram = LOADADDR (.cs3.extsram.bss) - LOADADDR (.cs3.extsram);
  __cs3_region_zero_size_extsram = SIZEOF(.cs3.extsram.bss);

  .cs3.extnand : ALIGN (8)
  {
    __cs3_region_start_extnand = .;
    *(.cs3.region-head.extnand)
    *(.extnand)
    . = ALIGN (8);
  } >extnand
  .cs3.extnand.bss :
  {
    *(.extnand.b .bss.extnand)
    . = ALIGN (8);
  } >extnand
  /* __cs3_region_end_extnand is deprecated */
  __cs3_region_end_extnand = __cs3_region_start_extnand + LENGTH(extnand);
  __cs3_region_size_extnand = LENGTH(extnand);
  __cs3_region_init_extnand = LOADADDR (.cs3.extnand);
  __cs3_region_init_size_extnand = LOADADDR (.cs3.extnand.bss) - LOADADDR (.cs3.extnand);
  __cs3_region_zero_size_extnand = SIZEOF(.cs3.extnand.bss);

  .data : ALIGN (8)
  {
    KEEP(*(.jcr))
    *(.got.plt) *(.got)
    *(.shdata)
    *(.data .data.* .gnu.linkonce.d.*)
    . = ALIGN (8);
    *(.ram)
    . = ALIGN (8);
    _edata = .;
  } >ram
  .bss : ALIGN (8)
  {
    *(.shbss)
    *(.bss .bss.* .gnu.linkonce.b.*)
    *(COMMON)
    . = ALIGN (8);
    *(.ram.b .bss.ram)
    . = ALIGN (8);
    _end = .;
    __end = .;
  } >ram
  /* __cs3_region_end_ram is deprecated */
  __cs3_region_end_ram = __cs3_region_start_ram + LENGTH(ram);
  __cs3_region_size_ram = LENGTH(ram);
  __cs3_region_init_ram = LOADADDR (.text);
  __cs3_region_init_size_ram = _edata - ADDR (.text);
  __cs3_region_zero_size_ram = _end - _edata;

  .stab 0 (NOLOAD) : { *(.stab) }
  .stabstr 0 (NOLOAD) : { *(.stabstr) }
  /* DWARF debug sections.
   * Symbols in the DWARF debugging sections are relative to
   * the beginning of the section so we begin them at 0.
   */
  /* DWARF 1 */
  .debug          0 : { *(.debug) }
  .line           0 : { *(.line) }
  /* GNU DWARF 1 extensions */
  .debug_srcinfo  0 : { *(.debug_srcinfo) }
  .debug_sfnames  0 : { *(.debug_sfnames) }
  /* DWARF 1.1 and DWARF 2 */
  .debug_aranges  0 : { *(.debug_aranges) }
  .debug_pubnames 0 : { *(.debug_pubnames) }
  /* DWARF 2 */
  .debug_info     0 : { *(.debug_info .gnu.linkonce.wi.*) }
  .debug_abbrev   0 : { *(.debug_abbrev) }
  .debug_line     0 : { *(.debug_line) }
  .debug_frame    0 : { *(.debug_frame) }
  .debug_str      0 : { *(.debug_str) }
  .debug_loc      0 : { *(.debug_loc) }
  .debug_macinfo  0 : { *(.debug_macinfo) }
  /* DWARF 2.1 */
  .debug_ranges   0 : { *(.debug_ranges) }
  /* SGI/MIPS DWARF 2 extensions */
  .debug_weaknames 0 : { *(.debug_weaknames) }
  .debug_funcnames 0 : { *(.debug_funcnames) }
  .debug_typenames 0 : { *(.debug_typenames) }
  .debug_varnames  0 : { *(.debug_varnames) }

  .note.gnu.arm.ident 0 : { KEEP (*(.note.gnu.arm.ident)) }
  .ARM.attributes 0 : { KEEP (*(.ARM.attributes)) }
  /DISCARD/ : { *(.note.GNU-stack) }
}
/* checksum: 39870816c687e324d390b216e */
