/*********************************************************************
*                SEGGER Microcontroller GmbH & Co. KG                *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2016 SEGGER Microcontroller GmbH & Co. KG         *
*                                                                    *
*     Internet: segger.com   Support: support_embos@segger.com       *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 4.16                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : startup_stm32f303.s
Purpose : Startup code and vector table for STM32F303 and CS
--------  END-OF-HEADER  ---------------------------------------------
*/
    
  .syntax unified
  .cpu cortex-m3
  .fpu softvfp
  .thumb

.global  Default_Handler
.global __Vectors
.global _start
.extern __cs3_stack
.extern __cs3_start_c

/**
 * @brief  This is the code that gets called when the processor first
 *          starts execution following a reset event. Only the absolutely
 *          necessary set is performed, after which the application
 *          supplied main() routine is called. 
 * @param  None
 * @retval : None
*/
    .thumb_func
_start:
    ldr r1,=__cs3_stack
    mov sp,r1

/*FPU settings*/
    ldr r0, =0xE000ED88
    ldr r1,[r0]
    orr r1,r1,#(0xF << 20)
    str r1,[r0]

/* Call the clock system intitialization function.*/
    bl  SystemInit

    ldr r1,=__cs3_start_c
    bx  r1


/**
 * @brief  This is the code that gets called when the processor receives an 
 *         unexpected interrupt.  This simply enters an infinite loop, preserving
 *         the system state for examination by a debugger.
 * @param  None     
 * @retval None       
*/
    .section  .text.Default_Handler,"ax",%progbits
Default_Handler:
Infinite_Loop:
  b  Infinite_Loop
  .size  Default_Handler, .-Default_Handler
/******************************************************************************
*
* The minimal vector table for a Cortex M3. Note that the proper constructs
* must be placed on this to ensure that it ends up at physical address
* 0x0000.0000.
* 
*******************************************************************************/
    .section .text.cs3.init,"ax",%progbits
    
__Vectors:
  .word  __cs3_stack
  .word  __cs3_reset
  .word  NMI_Handler
  .word  HardFault_Handler
  .word  MemManage_Handler
  .word  BusFault_Handler
  .word  UsageFault_Handler
  .word  0
  .word  0
  .word  0
  .word  0
  .word  SVC_Handler
  .word  DebugMon_Handler
  .word  0
  .word  PendSV_Handler
  .word  SysTick_Handler

  .word  WWDG_IRQHandler                   // Window WatchDog                                        
  .word  PVD_IRQHandler                    // PVD through EXTI Line detection                        
  .word  TAMPER_STAMP_IRQHandler           // Tamper and TimeStamps through the EXTI line            
  .word  RTC_WKUP_IRQHandler               // RTC Wakeup through the EXTI line                       
  .word  FLASH_IRQHandler                  // FLASH                                           
  .word  RCC_IRQHandler                    // RCC                                             
  .word  EXTI0_IRQHandler                  // EXTI Line0                                             
  .word  EXTI1_IRQHandler                  // EXTI Line1                                             
  .word  EXTI2_TS_IRQHandler               // EXTI Line2 and Touch Sense                                             
  .word  EXTI3_IRQHandler                  // EXTI Line3                                             
  .word  EXTI4_IRQHandler                  // EXTI Line4                                             
  .word  DMA1_Channel1_IRQHandler          // DMA1 Channel 1                                   
  .word  DMA1_Channel2_IRQHandler          // DMA1 Channel 2                                   
  .word  DMA1_Channel3_IRQHandler          // DMA1 Channel 3                                   
  .word  DMA1_Channel4_IRQHandler          // DMA1 Channel 4                                   
  .word  DMA1_Channel5_IRQHandler          // DMA1 Channel 5                                   
  .word  DMA1_Channel6_IRQHandler          // DMA1 Channel 6                                   
  .word  DMA1_Channel7_IRQHandler          // DMA1 Channel 7                                   
  .word  ADC1_2_IRQHandler                 // ADC1 and ADC2                            
  .word  USB_HP_CAN1_TX_IRQHandler         // USB Device High Priority or CAN1 TX                                               
  .word  USB_LP_CAN1_RX0_IRQHandler        // USB Device Low Priority or CAN1 RX0                                               
  .word  CAN1_RX1_IRQHandler               // CAN1 RX1                                               
  .word  CAN1_SCE_IRQHandler               // CAN1 SCE                                               
  .word  EXTI9_5_IRQHandler                // External Line[9:5]s                                    
  .word  TIM1_BRK_TIM15_IRQHandler         // TIM1 Break and TIM15                   
  .word  TIM1_UP_TIM16_IRQHandler          // TIM1 Update and TIM16                 
  .word  TIM1_TRG_COM_TIM17_IRQHandler     // TIM1 Trigger and Commutation and TIM17
  .word  TIM1_CC_IRQHandler                // TIM1 Capture Compare                                   
  .word  TIM2_IRQHandler                   // TIM2                                            
  .word  TIM3_IRQHandler                   // TIM3                                            
  .word  TIM4_IRQHandler                   // TIM4                                            
  .word  I2C1_EV_IRQHandler                // I2C1 Event                                             
  .word  I2C1_ER_IRQHandler                // I2C1 Error                                             
  .word  I2C2_EV_IRQHandler                // I2C2 Event                                             
  .word  I2C2_ER_IRQHandler                // I2C2 Error                                               
  .word  SPI1_IRQHandler                   // SPI1                                            
  .word  SPI2_IRQHandler                   // SPI2                                            
  .word  USART1_IRQHandler                 // USART1                                          
  .word  USART2_IRQHandler                 // USART2                                          
  .word  USART3_IRQHandler                 // USART3                                          
  .word  EXTI15_10_IRQHandler              // External Line[15:10]s                                  
  .word  RTC_Alarm_IRQHandler              // RTC Alarm (A and B) through EXTI Line                  
  .word  USBWakeUp_IRQHandler              // USB Wakeup through EXTI line                        
  .word  TIM8_BRK_IRQHandler               // TIM8 Break                  
  .word  TIM8_UP_IRQHandler                // TIM8 Update                
  .word  TIM8_TRG_COM_IRQHandler           // TIM8 Trigger and Commutation
  .word  TIM8_CC_IRQHandler                // TIM8 Capture Compare                                   
  .word  ADC3_IRQHandler                   // ADC3                                           
  .word  0                                 // Reserved                                            
  .word  0                                 // Reserved                                            
  .word  0                                 // Reserved                                            
  .word  SPI3_IRQHandler                   // SPI3                                            
  .word  UART4_IRQHandler                  // UART4                                           
  .word  UART5_IRQHandler                  // UART5                                           
  .word  TIM6_DAC_IRQHandler               // TIM6 and DAC1&2 underrun errors                   
  .word  TIM7_IRQHandler                   // TIM7                   
  .word  DMA2_Channel1_IRQHandler          // DMA2 Channel 1                                   
  .word  DMA2_Channel2_IRQHandler          // DMA2 Channel 2                                   
  .word  DMA2_Channel3_IRQHandler          // DMA2 Channel 3                                   
  .word  DMA2_Channel4_IRQHandler          // DMA2 Channel 4                                   
  .word  DMA2_Channel5_IRQHandler          // DMA2 Channel 5                                   
  .word  ADC4_IRQHandler                   // ADC4                                        
  .word  0                                 // Reserved                      
  .word  0                                 // Reserved                                               
  .word  COMP1_2_3_IRQHandler              // COMP1, COMP2 and COMP3                                               
  .word  COMP4_5_6_IRQHandler              // COMP4, COMP5 and COMP6                                              
  .word  COMP7_IRQHandler                  // COMP7                                               
  .word  0                                 // Reserved                                      
  .word  0                                 // Reserved                                   
  .word  0                                 // Reserved                                   
  .word  0                                 // Reserved                                   
  .word  0                                 // Reserved                                           
  .word  0                                 // Reserved                                             
  .word  0                                 // Reserved                                             
  .word  USB_HP_IRQHandler                 // USB High Priority remap                       
  .word  USB_LP_IRQHandler                 // USB Low Priority remap                    
  .word  USBWakeUp_RMP_IRQHandler          // USB Wakeup remap through EXTI                         
  .word  0                                 // Reserved                                       
  .word  0                                 // Reserved                                        
  .word  0                                 // Reserved                                      
  .word  0                                 // Reserved 
  .word  FPU_IRQHandler                    // FPU
  

                         
                         
/*******************************************************************************
*
* Provide weak aliases for each Exception handler to the Default_Handler. 
* As they are weak aliases, any function with the same name will override 
* this definition.
* 
*******************************************************************************/
   .weak      NMI_Handler
   .thumb_set NMI_Handler,Default_Handler
  
   .weak      HardFault_Handler
   .thumb_set HardFault_Handler,Default_Handler
  
   .weak      MemManage_Handler
   .thumb_set MemManage_Handler,Default_Handler
  
   .weak      BusFault_Handler
   .thumb_set BusFault_Handler,Default_Handler

   .weak      UsageFault_Handler
   .thumb_set UsageFault_Handler,Default_Handler

   .weak      SVC_Handler
   .thumb_set SVC_Handler,Default_Handler

   .weak      DebugMon_Handler
   .thumb_set DebugMon_Handler,Default_Handler

   .weak      PendSV_Handler
   .thumb_set PendSV_Handler,Default_Handler

   .weak      SysTick_Handler
   .thumb_set SysTick_Handler,Default_Handler              
 

   .weak      WWDG_IRQHandler
   .thumb_set WWDG_IRQHandler,Default_Handler  

   .weak      PVD_IRQHandler
   .thumb_set PVD_IRQHandler,Default_Handler    

   .weak      TAMPER_STAMP_IRQHandler
   .thumb_set TAMPER_STAMP_IRQHandler,Default_Handler    

   .weak      RTC_WKUP_IRQHandler
   .thumb_set RTC_WKUP_IRQHandler,Default_Handler    

   .weak      FLASH_IRQHandler
   .thumb_set FLASH_IRQHandler,Default_Handler    

   .weak      RCC_IRQHandler
   .thumb_set RCC_IRQHandler,Default_Handler    

   .weak      EXTI0_IRQHandler
   .thumb_set EXTI0_IRQHandler,Default_Handler    

   .weak      EXTI1_IRQHandler
   .thumb_set EXTI1_IRQHandler,Default_Handler    

   .weak      EXTI2_TS_IRQHandler
   .thumb_set EXTI2_TS_IRQHandler,Default_Handler    

   .weak      EXTI3_IRQHandler
   .thumb_set EXTI3_IRQHandler,Default_Handler  

   .weak      EXTI4_IRQHandler
   .thumb_set EXTI4_IRQHandler,Default_Handler    

   .weak      DMA1_Channel1_IRQHandler
   .thumb_set DMA1_Channel1_IRQHandler,Default_Handler    

   .weak      DMA1_Channel2_IRQHandler
   .thumb_set DMA1_Channel2_IRQHandler,Default_Handler    

   .weak      DMA1_Channel3_IRQHandler
   .thumb_set DMA1_Channel3_IRQHandler,Default_Handler    

   .weak      DMA1_Channel4_IRQHandler
   .thumb_set DMA1_Channel4_IRQHandler,Default_Handler    

   .weak      DMA1_Channel5_IRQHandler
   .thumb_set DMA1_Channel5_IRQHandler,Default_Handler    

   .weak      DMA1_Channel6_IRQHandler
   .thumb_set DMA1_Channel6_IRQHandler,Default_Handler    

   .weak      DMA1_Channel7_IRQHandler
   .thumb_set DMA1_Channel7_IRQHandler,Default_Handler    

   .weak      ADC1_2_IRQHandler
   .thumb_set ADC1_2_IRQHandler,Default_Handler    

   .weak      USB_HP_CAN1_TX_IRQHandler
   .thumb_set USB_HP_CAN1_TX_IRQHandler,Default_Handler    

   .weak      USB_LP_CAN1_RX0_IRQHandler
   .thumb_set USB_LP_CAN1_RX0_IRQHandler,Default_Handler    

   .weak      CAN1_RX1_IRQHandler
   .thumb_set CAN1_RX1_IRQHandler,Default_Handler    

   .weak      CAN1_SCE_IRQHandler
   .thumb_set CAN1_SCE_IRQHandler,Default_Handler    

   .weak      EXTI9_5_IRQHandler
   .thumb_set EXTI9_5_IRQHandler,Default_Handler    

   .weak      TIM1_BRK_TIM15_IRQHandler
   .thumb_set TIM1_BRK_TIM15_IRQHandler,Default_Handler    

   .weak      TIM1_UP_TIM16_IRQHandler
   .thumb_set TIM1_UP_TIM16_IRQHandler,Default_Handler    

   .weak      TIM1_TRG_COM_TIM17_IRQHandler
   .thumb_set TIM1_TRG_COM_TIM17_IRQHandler,Default_Handler    
        
   .weak      TIM1_CC_IRQHandler
   .thumb_set TIM1_CC_IRQHandler,Default_Handler    

   .weak      TIM2_IRQHandler
   .thumb_set TIM2_IRQHandler,Default_Handler    

   .weak      TIM3_IRQHandler
   .thumb_set TIM3_IRQHandler,Default_Handler    

   .weak      TIM4_IRQHandler
   .thumb_set TIM4_IRQHandler,Default_Handler    

   .weak      I2C1_EV_IRQHandler
   .thumb_set I2C1_EV_IRQHandler,Default_Handler    

   .weak      I2C1_ER_IRQHandler
   .thumb_set I2C1_ER_IRQHandler,Default_Handler    

   .weak      I2C2_EV_IRQHandler
   .thumb_set I2C2_EV_IRQHandler,Default_Handler    

   .weak      I2C2_ER_IRQHandler
   .thumb_set I2C2_ER_IRQHandler,Default_Handler    

   .weak      SPI1_IRQHandler
   .thumb_set SPI1_IRQHandler,Default_Handler    

   .weak      SPI2_IRQHandler
   .thumb_set SPI2_IRQHandler,Default_Handler    

   .weak      USART1_IRQHandler
   .thumb_set USART1_IRQHandler,Default_Handler    

   .weak      USART2_IRQHandler
   .thumb_set USART2_IRQHandler,Default_Handler    

   .weak      USART3_IRQHandler
   .thumb_set USART3_IRQHandler,Default_Handler    

   .weak      EXTI15_10_IRQHandler
   .thumb_set EXTI15_10_IRQHandler,Default_Handler    

   .weak      RTC_Alarm_IRQHandler
   .thumb_set RTC_Alarm_IRQHandler,Default_Handler    

   .weak      USBWakeUp_IRQHandler
   .thumb_set USBWakeUp_IRQHandler,Default_Handler    
      
   .weak      TIM8_BRK_IRQHandler
   .thumb_set TIM8_BRK_IRQHandler,Default_Handler    

   .weak      TIM8_UP_IRQHandler
   .thumb_set TIM8_UP_IRQHandler,Default_Handler    

   .weak      TIM8_TRG_COM_IRQHandler
   .thumb_set TIM8_TRG_COM_IRQHandler,Default_Handler    

   .weak      TIM8_CC_IRQHandler
   .thumb_set TIM8_CC_IRQHandler,Default_Handler    

   .weak      ADC3_IRQHandler
   .thumb_set ADC3_IRQHandler,Default_Handler    

   .weak      SPI3_IRQHandler
   .thumb_set SPI3_IRQHandler,Default_Handler    

   .weak      UART4_IRQHandler
   .thumb_set UART4_IRQHandler,Default_Handler    

   .weak      UART5_IRQHandler
   .thumb_set UART5_IRQHandler,Default_Handler    

   .weak      TIM6_DAC_IRQHandler
   .thumb_set TIM6_DAC_IRQHandler,Default_Handler    

   .weak      TIM7_IRQHandler
   .thumb_set TIM7_IRQHandler,Default_Handler    

   .weak      DMA2_Channel1_IRQHandler
   .thumb_set DMA2_Channel1_IRQHandler,Default_Handler    

   .weak      DMA2_Channel2_IRQHandler
   .thumb_set DMA2_Channel2_IRQHandler,Default_Handler    

   .weak       DMA2_Channel3_IRQHandler
   .thumb_set DMA2_Channel3_IRQHandler,Default_Handler    

   .weak      DMA2_Channel4_IRQHandler
   .thumb_set DMA2_Channel4_IRQHandler,Default_Handler    

   .weak      DMA2_Channel5_IRQHandler
   .thumb_set DMA2_Channel5_IRQHandler,Default_Handler    
        
   .weak      ADC4_IRQHandler
   .thumb_set ADC4_IRQHandler,Default_Handler    
        
   .weak      COMP1_2_3_IRQHandler
   .thumb_set COMP1_2_3_IRQHandler,Default_Handler    
        
   .weak      COMP4_5_6_IRQHandler
   .thumb_set COMP4_5_6_IRQHandler,Default_Handler    
        
   .weak       COMP7_IRQHandler
   .thumb_set COMP7_IRQHandler,Default_Handler    
        
   .weak      USB_HP_IRQHandler
   .thumb_set USB_HP_IRQHandler,Default_Handler    
        
   .weak      USB_LP_IRQHandler
   .thumb_set USB_LP_IRQHandler,Default_Handler    
        
   .weak      USBWakeUp_RMP_IRQHandler
   .thumb_set USBWakeUp_RMP_IRQHandler,Default_Handler    
        
   .weak      FPU_IRQHandler
   .thumb_set FPU_IRQHandler,Default_Handler    

