/*********************************************************************
*                SEGGER Microcontroller GmbH & Co. KG                *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2016 SEGGER Microcontroller GmbH & Co. KG         *
*                                                                    *
*     Internet: segger.com   Support: support_embos@segger.com       *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 4.16                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : OS_MallocLock.c
Purpose : embOS implementation of thread safe malloc function locking
--------  END-OF-HEADER  ---------------------------------------------
*/

#include <malloc.h>
#include "RTOS.h"

/*********************************************************************
*
*       Static variables
*
**********************************************************************
*/

static OS_RSEMA      _MallocSema;
static unsigned char _MallocIsInited;

/*********************************************************************
*
*       Static functions
*
**********************************************************************
*/

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       __mallock_lock()
*/
void __malloc_lock(void) {
  if (OS_IsRunning()) {
    //
    // Heap access locking is required when called from tasks
    //
    OS_EnterRegion();
    if (!_MallocIsInited) {
      OS_CREATERSEMA(&_MallocSema);
      _MallocIsInited = 1;
    }
    OS_LeaveRegion();
    OS_Use(&_MallocSema);
  }
}

/*********************************************************************
*
*       __mallock_lock()
*/
void __malloc_unlock(void) {
  if (OS_IsRunning()) {
	//
	// Heap access locking is required when called from tasks
	//
    OS_Unuse(&_MallocSema);
  }
}

/*******  End Of File ***********************************************/
