/*********************************************************************
*                SEGGER Microcontroller GmbH & Co. KG                *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2016 SEGGER Microcontroller GmbH & Co. KG         *
*                                                                    *
*     Internet: segger.com   Support: support_embos@segger.com       *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 4.16                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : OS_Stack.c
Purpose : Stack information
--------  END-OF-HEADER  ---------------------------------------------
*/
#include <errno.h>

/*********************************************************************
*
*       Configuration
*
*       Please define here or as project setting your
*       stack and heap size
*/

#ifndef   _STACK_SIZE_
  #define _STACK_SIZE_ 1024
#endif

#ifndef   _HEAP_SIZE_
  #define _HEAP_SIZE_  4096
#endif

/*********************************************************************
*
*       Const data
*/

const unsigned int OS_StackSize = _STACK_SIZE_;
const unsigned int OS_HeapSize  = _HEAP_SIZE_;


/*********************************************************************
*
*   _sbrk()
*
*   We have to override the original function since we use our own stack
*   and heap defines
*/
extern unsigned int __cs3_heap_start;
static void* heap_ptr = (void*)&__cs3_heap_start;
void* _sbrk (int incr) {
  void* heap_current;
  if (((unsigned int)heap_ptr + incr) > (unsigned int)&__cs3_heap_start + _HEAP_SIZE_) {
    errno = ENOMEM;
    return (void*) -1;
  } else {
	heap_current = heap_ptr;
    heap_ptr += incr;
  }
  return heap_current;
}

/*****  End of File  ************************************************/
